@@ -1,11 +1,12 @@
 test_that("test get forms list", {
   vcr::use_cassette("ns_get_forms", {
-    formslist <- ns_get_forms()
-    formslist_raw <- ns_get_forms(asis = TRUE)
+    with_mocked_nettskjema_auth(
+      formslist <- ns_get_forms()
+    )
   })
 
   expect_is(formslist, "data.frame")
-  expect_equal(nrow(formslist), 191)
+  expect_equal(nrow(formslist), 1)
   expect_equal(ncol(formslist), 14)
   expect_equal(
     names(formslist),
@@ -27,10 +28,18 @@ test_that("test get forms list", {
     )
   )
   expect_is(formslist$isDictaphone, "logical")
+})
+
+
+test_that("test get raw forms list", {
+  vcr::use_cassette("ns_get_forms_raw", {
+    with_mocked_nettskjema_auth(
+      formslist_raw <- ns_get_forms(asis = TRUE)
+    )
+  })
 
-  # raw
   expect_is(formslist_raw, "list")
-  expect_equal(length(formslist), 14)
+  expect_equal(length(formslist_raw), 1)
   expect_null(names(formslist_raw))
   expect_equal(
     names(formslist_raw[[1]]),
@@ -51,5 +60,4 @@ test_that("test get forms list", {
       "open"
     )
   )
-  expect_is(formslist$isDictaphone, "logical")
 })
